# euniverse: A tool to explore Euclid color images created with eummy.

**euniverse** is a Python UI designed to display color images from the Euclid space telescope, created with **eummy** (see <https://pypi.org/project/eummy>). You can overlay Euclid catalogs, create image cutouts, and change the color contrast. **euniverse** also has the option to create manually defined target lists in case you spot something interesting. 

For more details about the Euclid space telescope visit <https://euclid-ec.org>.

## Installation

You can install **euniverse** directly from PyPI using pip, pip3, or pipx:

```bash
pipx install euniverse
```

Note: This will automatically install required dependencies.

## Usage

**euniverse** is designed to be used as a command-line tool. After installation, the euniverse command will be available in your terminal.
